CounterManager

Struct CounterManager 

pub struct CounterManager { /* private fields */ }
Counter manager for different storage modes.

Implementations

Source

impl CounterManager

pub fn new(mode: CounterMode) -> Self

Create a new counter manager.

pub fn with_in_bin_value(mode: CounterMode, initial_value: u64) -> Self

Create a counter manager with an initial in-bin value.

pub fn mode(&self) -> &CounterMode

Get the counter mode.

pub fn get(&self) -> Result<u64>

Get the current counter value.

pub fn reserve(&mut self, count: u64) -> Result<u64>

Increment counter and return the starting value for a batch.

For a batch of count codes, returns the starting counter value and increments the stored counter by count.

pub fn set(&mut self, value: u64) -> Result<()>

Set the counter value (for initialization or reset).

pub fn is_in_bin_modified(&self) -> bool

Check if the in-bin counter has been modified.

pub fn in_bin_value(&self) -> u64

Get the in-bin counter value.

pub fn mark_saved(&mut self)

Mark the in-bin counter as saved.

pub fn set_mode(&mut self, mode: CounterMode)

Update the counter mode.